@@ -3,6 +3,13 @@ from typing import Callable, TypeVar
 
 
 T = TypeVar('T')
+_is_ip_header_names = {
+    b'client-ip',
+    b'x-forwarded-for',
+    b'x-real-ip',
+    b'remote_addr'
+}
+
 _is_rq = lambda x: isinstance(x, Request)
 _is_ws = lambda x: isinstance(x, WebSocket)
 
@@ -19,6 +26,12 @@ async def get_file(rq: Request, file_name: str):
     return _get_list_item(files, lambda x: x.name == bfile_name)
 
 
+def get_ip(rq_or_ws: Request | WebSocket):
+    for name in _is_ip_header_names:
+        if ip := rq_or_ws.headers.get(name):
+            return ip[0].decode()
+
+
 def get_rq(args: tuple) -> Request | None:
     return _get_list_item(args, lambda x: _is_rq(x))
 
